@@ -56,7 +56,7 @@ module Kbgen (
     ParamResolvedType(..),
     ClassName(..),
     ParamName(..),
-    CallMethodOfSuper(..),
+    CallMethodOfClass(..),
     ConstString(..),
     ArgForCall(..),
     MethodOfClass(..),
@@ -205,8 +205,8 @@ data ParamResolvedType = ParamResolvedType
 --
 -- @
 -- skip_level_subclass_of( Subclass, \'tornado.web.RequestHandler\' ) :-
---     kb_class_name( Class, ClassType ),
---     kb_class_named_super( Subclass, ClassType ),
+--     kb_class_name( Class, ClassName ),
+--     kb_class_named_super( Subclass, ClassName ),
 --     kb_class_resolved_super( Class, \'tornado.web.RequestHandler\' ).
 -- @
 --
@@ -321,21 +321,22 @@ data ParamName = ParamName
 --
 -- @
 -- user_controlled_query_argument( Call ) :-
---     kb_call_method_of_super( Call, \'get_query_argument\', \'tornado.web.RequestHandler\' ),
+--     kb_call_method_of_class( Call, \'get_query_argument\', Class ),
+--     kb_class_has_resolved_super( Class, \'tornado.web.RequestHandler\'),
 --     kb_arg_i_for_call( QueryParamName, 0, Call),
 --     kb_const_string( QueryParamName, _ ).
---
 -- @
 --
 -- Other facts combined in this predicate:
 --
+--     * 'ClassResolvedSuper'
 --     * 'ArgiForCall'
 --     * 'ConstString'
 --
-data CallMethodOfSuper = CallMethodOfSuper
+data CallMethodOfClass = CallMethodOfClass
     Call -- ^
     MethodName -- ^
-    ResolvedSuper -- ^
+    Class -- ^
     deriving ( Show, Eq, Ord, Generic, ToJSON, FromJSON )
 
 -- |
@@ -514,7 +515,7 @@ data Fact
    | ParamiOfCallableCtor ParamiOfCallable
    | KeywordArgForCallCtor KeywordArgForCall
    | ParamResolvedTypeCtor ParamResolvedType
-   | CallMethodOfSuperCtor CallMethodOfSuper
+   | CallMethodOfClassCtor CallMethodOfClass
    | ClassResolvedSuperCtor ClassResolvedSuper
    | CallableAnnotationCtor CallableAnnotation
    deriving ( Show, Eq, Ord, Generic, ToJSON, FromJSON )
@@ -541,7 +542,7 @@ prologify (ClassNamedSuperCtor content) = prologifyClassNamedSuper content
 prologify (ClassAnnotationCtor content) = prologify_ClassAnnotation content
 prologify (ParamiOfCallableCtor content) = prologify_ParamiOfCallable content
 prologify (ParamResolvedTypeCtor content) = prologify_ParamResolvedType content
-prologify (CallMethodOfSuperCtor content) = prologify_CallMethodOfSuper content
+prologify (CallMethodOfClassCtor content) = prologify_CallMethodOfClass content
 prologify (KeywordArgForCallCtor content) = prologify_KeywordArgForCall content
 prologify (ClassResolvedSuperCtor content) = prologifyClassResolvedSuper content
 prologify (CallableAnnotationCtor content) = prologify_CallableAnnotation content
@@ -552,11 +553,11 @@ prologify_ParamResolvedType' l fqn = printf "kb_param_has_type( %s, \'%s\' )." (
 prologify_ParamResolvedType :: ParamResolvedType -> String
 prologify_ParamResolvedType (ParamResolvedType (Param loc) (ResolvedType (Fqn content))) = prologify_ParamResolvedType' loc content
 
-prologify_CallMethodOfSuper' :: Location -> String -> String -> String
-prologify_CallMethodOfSuper' call method super = printf "kb_call_method_of_super( %s, \'%s\', \'%s\' )." (locationify call) method super
+prologify_CallMethodOfClass' :: Location -> String -> Location -> String
+prologify_CallMethodOfClass' call method klass = printf "kb_call_method_of_class( %s, \'%s\', %s )." (locationify call) method (locationify klass)
 
-prologify_CallMethodOfSuper :: CallMethodOfSuper -> String
-prologify_CallMethodOfSuper (CallMethodOfSuper (Call loc) (MethodName m) (ResolvedSuper (Fqn s))) = prologify_CallMethodOfSuper' loc m s
+prologify_CallMethodOfClass :: CallMethodOfClass -> String
+prologify_CallMethodOfClass (CallMethodOfClass (Call loc) (MethodName m) (Class c)) = prologify_CallMethodOfClass' loc m c
 
 prologify_ParamName' :: Location -> String -> String
 prologify_ParamName' l name = printf "kb_param_has_name( %s, \'%s\' )." (locationify l) name
